@@ -151,11 +151,11 @@ class videourl():
         self.mode = AES.MODE_CBC
         self.size = AES.block_size
         self.padder = "\x08\x0e\x03\x08\t\x03\x04\t"
-        self.pad = lambda s: s + self.padder[(len(self.padder) - len(s) % 16) :]
+        self.pad = lambda s: s + chr(len(s) % 16) * (16 - len(s) % 16) 
         self.iv = binascii.unhexlify(
-            bytes('31323835363732393835323338333933'.encode("utf-8")))
+            bytes('34373730343738393639343138323637'.encode("utf-8")))
         self.key = binascii.unhexlify(bytes(
-            "3235373136353338353232393338333936313634363632323738383333323838".encode("utf-8")))
+            "3633393736383832383733353539383139363339393838303830383230393037".encode("utf-8")))
 
     def get_entry(self):
         """
@@ -187,7 +187,7 @@ class videourl():
     def get_crypto(self):
         r = self.session.get(self.entry.embed_url)
         soup = BeautifulSoup(r.text, "html.parser")
-        crypto = soup.find("script", {"data-name": "crypto"})
+        crypto = soup.find("script", {"data-name": "episode"})
         loc_err(crypto, self.entry.embed_url, "crypto")
         return crypto["data-value"]
 
@@ -232,15 +232,16 @@ class videourl():
         """
 
         self.entry.quality = ""
-        if 'fc24fc6eef71638a72a9b19699526dcb' in json_data[0]['file']:
+        if 'fc24fc6eef71638a72a9b19699526dcb' in json_data[0]['file'] or 'm3u8' in json_data[0]['file']:
             r = self.session.get(json_data[0]['file'], headers={
                                  'referer': self.entry.embed_url})
-            
             qualitys = re.findall(r'(?<=\d\d\dx)\d+', r.text)
             quality_links = [x for x in r.text.split('\n')]
             quality_links = [x for x in quality_links if not x.startswith('#')]
-            qualitys.reverse()
-            quality_links.reverse()
+            if 'fc24fc6eef71638a72a9b19699526dcb' in json_data[0]['file']:
+                qualitys.reverse()
+                quality_links.reverse()
+
             quality_links = list(filter(None, quality_links))
 
 
@@ -269,13 +270,12 @@ class videourl():
 
 
 
-        if 'fc24fc6eef71638a72a9b19699526dcb.com' in json_data[0]['file']:
-            self.entry.stream_url = json_data[0]['file'].replace(
-                'playlist.m3u8', '') + q
+        if 'fc24fc6eef71638a72a9b19699526dcb.com' in json_data[0]['file'] or 'm3u8' in json_data[0]['file']:
+            self.entry.stream_url = json_data[0]['file'].rsplit(
+                '/', 1)[0] + "/" + q
         else:
             self.entry.stream_url = q
 
-
         chosen_quality = q.split("/")
         
         for _qual in chosen_quality:
